import click
from nomad_media_cli.helpers.utils import initialize_sdk

@click.command()
@click.option("--id", required=True, help="The id of the asset.")
@click.option("--related-content-id", required=True, help="The id of the related content.")
@click.pass_context
def add_asset_related_content(ctx, id, related_content_id):
    """Add related content to asset"""
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]
    
    try:
        nomad_sdk.add_related_content(id, related_content_id, "asset")
        click.echo({ "message": "Related content added to asset." })
    except Exception as e:
        click.echo({ "error": f"Error adding related content to asset: {e}" })


from nomad_media_cli.helpers.utils import initialize_sdk
from nomad_media_cli.helpers.get_content_definition_id import get_content_definition_id

import click
import json
import sys

@click.command()
@click.option("--id", required=True, help="Asset id to list the related contents for.")
@click.pass_context
def list_asset_related_contents(ctx, id):
    """List related contents"""    
    
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]

    try:    
        asset_metadata = nomad_sdk.get_asset_details(id)
        
        related_contents = asset_metadata["relatedContent"]
        
        click.echo(json.dumps(related_contents, indent=4))

    except Exception as e:
        click.echo({ "error": f"Error listing related contents: {e}" })
        sys.exit(1)


import click
import json
from nomad_media_cli.helpers.utils import initialize_sdk

@click.command()
@click.option("--id", required=True, help="The id of the asset.")
@click.option("--name", help="The display name of the asset.")
@click.option("--date", help="The display date of the asset.")
@click.option("--custom-properties", help="The custom properties of the asset. Must be in JSON format. Example: '{\"key\": \"value\"}'")
@click.pass_context
def add_asset_properties(ctx, id, name, date, custom_properties):
    """Add custom properties to asset"""
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]
    
    try:
        try:
            custom_properties = json.loads(custom_properties)
        except:
            click.echo({ "error": "Custom properties must be in JSON format." })
            return      

        nomad_sdk.add_custom_properties(id, name, date, custom_properties)
        click.echo({ "message": "Custom properties added to asset." })
    except Exception as e:
        click.echo({ "error": f"Error adding custom properties to asset." })


import click
import sys
from nomad_media_cli.helpers.utils import initialize_sdk

@click.command()
@click.option("--live-input-id", required=True, help="The ID of the live input.")
@click.pass_context
def delete_live_input(ctx, live_input_id):
    """Delete live input"""
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]

    try:
        nomad_sdk.delete_live_input(live_input_id)
        click.echo("Live input deleted successfully.")

    except Exception as e:
        click.echo({"error": f"Error deleting live input: {e}"})
        sys.exit(1)


import click
from nomad_media_cli.helpers.utils import initialize_sdk

@click.command()
@click.option("--id", required=True, help="The id of the asset.")
@click.option("--collection-id", required=True, help="The id of the collection.")
@click.pass_context
def remove_asset_collection(ctx, id, collection_id):
    """Remove collection from asset"""
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]
    
    try:
        nomad_sdk.remove_tag_or_collection("collection", id, "asset", collection_id)
        click.echo({ "message": "Collection removed from asset." })
    except Exception as e:
        click.echo({ "error": f"Error removing collection from asset: {e}" })


import click
import json
import sys
from nomad_media_cli.helpers.utils import initialize_sdk

@click.command()
@click.option("--live-channel-id", required=True, help="The ID of the live channel to clip.")
@click.option("--start-time-code", required=False, help="The start time code of the live channel to clip.")
@click.option("--end-time-code", required=False, help="The end time code of the live channel to clip.")
@click.option("--title", required=False, help="The title of the live channel to clip.")
@click.option("--output-folder-id", required=True, help="The output folder ID of the live channel to clip.")
@click.option("--tags", required=False, help="The tags of the live channel to clip in JSON list format.")
@click.option("--collections", required=False, help="The collections of the live channel to clip in JSON list format.")
@click.option("--related-contents", required=False, help="The related contents of the live channel to clip in JSON list format.")
@click.option("--video-bitrate", required=False, type=click.INT, help="The video bitrate of the live channel to clip.")
@click.option("--audio-tracks", required=False, help="The audio tracks of the live channel to clip in JSON list format.")
@click.pass_context
def clip_live_channel(ctx, live_channel_id, start_time_code, end_time_code, title, output_folder_id, tags, collections, related_contents, video_bitrate, audio_tracks):
    """Clip live channel"""
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]

    try:
        result = nomad_sdk.clip_live_channel(
            live_channel_id,
            start_time_code,
            end_time_code,
            title,
            output_folder_id,
            json.loads(tags) if tags else None,
            json.loads(collections) if collections else None,
            json.loads(related_contents) if related_contents else None,
            video_bitrate,
            json.loads(audio_tracks) if audio_tracks else None
        )
        click.echo(json.dumps(result, indent=4))

    except Exception as e:
        click.echo({"error": f"Error clipping live channel: {e}"})
        sys.exit(1)


import click
import sys
from nomad_media_cli.helpers.utils import initialize_sdk

@click.command()
@click.option("--live-operator-id", required=True, help="The ID of the live operator.")
@click.pass_context
def cancel_broadcast(ctx, live_operator_id):
    """Cancel broadcast"""
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]

    try:
        nomad_sdk.cancel_broadcast(live_operator_id)
        click.echo("Broadcast canceled successfully.")

    except Exception as e:
        click.echo({"error": f"Error canceling broadcast: {e}"})
        sys.exit(1)


import click
import json
import sys
from nomad_media_cli.helpers.utils import initialize_sdk
from nomad_media_cli.helpers.get_content_definition_id import get_content_definition_id

@click.command()
@click.option("--id", required=True, help="The ID of the content.")
@click.option("--url", help="The Nomad URL of the Asset (file or folder) to add the collection to (bucket::object-key).")
@click.option("--object-key", help="Object-key only of the Asset (file or folder) to add the collection to. This option assumes the default bucket that was previously set with the `set-bucket` command.")
@click.option("--collection-name", help="The name of the collection.")
@click.option("--collection-id", help="The ID of the collection.")
@click.pass_context
def add_asset_collection(ctx, id, url, object_key, collection_name, collection_id):
    """Add collection to content"""
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]
    
    if url or object_key:
        if url and "::" not in url:
            click.echo({ "error": "Please provide a valid path or set the default bucket." })               
            sys.exit(1)
        if object_key:
            if "bucket" in ctx.obj:
                url = f"{ctx.obj['bucket']}::{object_key}"
            else:
                click.echo({ "error": "Please set bucket using `set-bucket` or use url." })
                sys.exit(1)
                
        url_search_results = nomad_sdk.search(None, None, None, [{
            "fieldName": "url",
            "operator": "equals",
            "values": url
        }], None, None, None, None, None, None, None, None, None, None, None)
        
        if not url_search_results or len(url_search_results["items"] == 0):
            click.echo({ "error": f"URL {url} not found." })
            sys.exit(1)
            
        id = url_search_results["items"][0]["id"]

    try:
        offset = 0
        collection_content_definition_id = get_content_definition_id(ctx, "Collection")
        while not collection_id:
            collections = nomad_sdk.search(None, offset, None, [{
                "fieldName": "contentDefinitionId",
                "operator": "equals",
                "values": collection_content_definition_id
            }], None, None, None, None, None, None, None, None, None, None, None)
            
            if len(collections["items"]) == 0:
                break
            
            for collection in collections["items"]:
                if collection.get("title") == collection_name:
                    collection_id = collection["id"]
                    break
                
            offset += 1

        if collection_id: collection_name = None

        result = nomad_sdk.add_tag_or_collection(
            "collection",
            id,
            "asset",
            collection_name,
            collection_id,
            not collection_id
        )
        
        click.echo(json.dumps(result, indent=4))

    except Exception as e:
        click.echo({"error": f"Error adding collection: {e}"})
        sys.exit(1)


import click
import sys
from nomad_media_cli.helpers.utils import initialize_sdk

@click.command()
@click.option("--schedule-id", required=True, help="The ID of the intelligent schedule to be deleted.")
@click.pass_context
def delete_intelligent_schedule(ctx, schedule_id):
    """Delete intelligent schedule"""
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]

    try:
        nomad_sdk.delete_intelligent_schedule(schedule_id)
        click.echo("Intelligent schedule deleted successfully.")

    except Exception as e:
        click.echo({"error": f"Error deleting intelligent schedule: {e}"})
        sys.exit(1)